<div align="center">
  <img src="https://github.com/TeletcheaLab/libprotein/blob/main/pypi_packaging/banner512x125.png" alt="Logo">
</div>

# Libprotein
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

This module allows to analyze existing data to qualify a protein sequence in order to evaluate the sequence knowledge available in various databases.

_Description à venir_